@@ -1,4 +1,5 @@
 import logging
+from typing import Callable, Dict
 
 from lunr.exceptions import BaseLunrException
 from lunr.token import Token
@@ -12,7 +13,7 @@ class Pipeline:
 
     """
 
-    registered_functions = {}
+    registered_functions: Dict[str, Callable] = {}
 
     def __init__(self):
         self._stack = []
@@ -26,8 +27,9 @@ class Pipeline:
     # TODO: add iterator methods?
 
     @classmethod
-    def register_function(cls, fn, label):
+    def register_function(cls, fn, label=None):
         """Register a function with the pipeline."""
+        label = label or fn.__name__
         if label in cls.registered_functions:
             log.warning("Overwriting existing registered function %s", label)
 
